package stamp.peripheral.io;

import stamp.core.*;
import stamp.peripheral.io.I2C;

/**
 * This class provides an interface to the Maxim MAX1238 (12-bit ADC)
 *
 *
 * To create a MAX1238 object, the programmer will usually define a [shared]
 * I2C bus object first and pass this object to the MAX1238 constructor.
 * <p>
 * <code>
 *   I2C ioBus = new I2C(CPU.pin0, CPU.pin1);
 *   MAX1238 ioPort = new MAX1238(ioBus, 0x00);
 * </code>
 * <p>
 *
 * For additonal operational details, consult Maxim documentation for the
 * MAX1238.
 *
 * @author diafysal
 * @version 0.0  2005
 */
public class MAX1238 {

  private I2C bus;                        // I2C bus pins
  private int addr = 0x00;                // address


  /**
   * Create MAX1238 object
   *
   * @param bus I2C bus object
   * @param devAddr Device address (8 bit, 0000 000x )
   */
  public MAX1238 (I2C bus, int devAddr) {
    this.bus = bus;
    this.addr = (devAddr & 0xfe);
  }


  /**
   * Check for presence of specific device.
   *
   * @return True if device exists on bus
   */
  public boolean isPresent() {
    boolean deviceAck;

    bus.start();
    deviceAck = bus.write(addr);
    bus.stop();

    return deviceAck;
  }


  /**
   * Setup of MAX1238.
   *
   * @param outData Setup or configuration byte to write to MAX1238
   */
   public boolean write(int outData) {
    boolean deviceAck;

    bus.start();
    bus.write(addr);                      // send write addres
    deviceAck = bus.write(outData);       // write setup or configuration byte
    bus.stop();

    return deviceAck;
  }


  /**
   * Get MAX1238 input
   *
   * @return dataIn from MAX1238 input
   */
  public int read() {
    int dataIn;

    bus.start();
    bus.write(addr | 1);                  // send read address (bit zero is set)
//CPU.delay( 1 );       // I'm not sure about I2C clock stretch (see Maxim pdf)
    dataIn = bus.read(bus.ACK);           // read 4 MSBs
    dataIn <<= 8;
    dataIn = dataIn | bus.read(bus.ACK);  // read 8 LSBs
    bus.stop();
    dataIn &= 0x0fff;   //remove 4 bits (always 1111 ?)

    return (dataIn);
  }
}